<?php
require_once plugin_dir_path(__FILE__) . '../config/config.php';

if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Function to fetch cities
function emlak_real_estate_fetch_cities($model) {
    $api_url = EMLAK_API_BASE_URL . 'cities?country=Turkey';
    // Dynamically add other filter parameters if they exist
    if (!empty($model)) {
        $api_url .= '&model=' . sanitize_text_field($model);
    }
    $response = wp_remote_get( $api_url, array(
        'headers' => array(
            'Accept' => 'application/json',
            'access-key' => EMLAK_API_ACCESS_KEY, // Use your access key here
        ),
    ));

    if ( is_wp_error( $response ) ) {
        return array('error' => 'Unable to fetch cities.');
    }

    $body = wp_remote_retrieve_body( $response );
    return json_decode( $body, true );
}

// Function to fetch places based on city ID
function emlak_real_estate_fetch_places($city_id, $model) {
    $api_url = EMLAK_API_BASE_URL . 'places?model=' . $model . '&city=' . intval($city_id);
    $response = wp_remote_get( $api_url, array(
        'headers' => array(
            'Accept' => 'application/json',
            'access-key' => EMLAK_API_ACCESS_KEY, // Use your access key here
        ),
    ));

    if ( is_wp_error( $response ) ) {
        return array('error' => 'Unable to fetch places.');
    }

    $body = wp_remote_retrieve_body( $response );
    return json_decode( $body, true ); 
}

// Register AJAX actions for fetching towns
add_action('wp_ajax_fetch_town', 'handle_fetch_town');
add_action('wp_ajax_nopriv_fetch_town', 'handle_fetch_town');

// Function to dynamically fetch properties based on filters
function emlak_real_estate_fetch_next_filter($current_filter, $filters = []) {
    // Determine which filter to request based on the current filter
    if (!empty($filters['model']) && $filters['model'] === 'project') {
        $filter_map = [
            'town' => 'pattern',
            'pattern' => 'room',
            'room' => 'lounge'
        ];
    } else {
        $filter_map = [
            'town' => 'category',
            'category' => 'pattern',
            'pattern' => 'room',
            'room' => 'lounge'
        ];
    }

    // Get the next filter to fetch
    $next_filter = isset($filter_map[$current_filter]) ? $filter_map[$current_filter] : '';

    if (empty($next_filter)) {
        return array('error' => 'Invalid filter request.');
    }

    // Build the base API URL with the model and language
    $api_url = EMLAK_API_BASE_URL . 'properties-filters/advanced?lang=en&filter=' . $next_filter;

    // Dynamically add other filter parameters if they exist
    if (!empty($filters['model'])) {
        $api_url .= '&model=' . sanitize_text_field($filters['model']);
    }
    if (!empty($filters['city'])) {
        $api_url .= '&city=' . intval($filters['city']);
    }
    if (!empty($filters['town'])) {
        $api_url .= '&town=' . $filters['town'];
    }
    if (!empty($filters['category']) && $current_filter !== 'project') {
        $api_url .= '&category=' . intval($filters['category']);
    }
    if (!empty($filters['pattern'])) {
        $api_url .= '&patternId=' . sanitize_text_field($filters['pattern']);
    }
    if (!empty($filters['room'])) {
        $api_url .= '&roomId=' . intval($filters['room']);
    }

    // Send the request to the API
    $response = wp_remote_get($api_url, array(
        'headers' => array(
            'Accept' => 'application/json',
            'access-key' => EMLAK_API_ACCESS_KEY,
        ),
    ));

    // Check for errors in the response
    if (is_wp_error($response)) {
        return array('error' => 'Unable to fetch data for ' . $next_filter);
    }

    // Retrieve and return the response body as JSON
    $body = wp_remote_retrieve_body($response);
    return json_decode($body, true);
    // return $api_url;
}

// Register AJAX handler for fetching the next filter
add_action('wp_ajax_nopriv_fetch_next_filter', 'handle_fetch_next_filter');
add_action('wp_ajax_fetch_next_filter', 'handle_fetch_next_filter');
function handle_fetch_next_filter() {
    // Get the current filter and other parameters from the AJAX request
    $current_filter = isset($_POST['currentFilter']) ? sanitize_text_field($_POST['currentFilter']) : '';
    $filters = array(
        'model'     => isset($_POST['model']) ? sanitize_text_field($_POST['model']) : 'resale',
        'city'      => isset($_POST['city']) ? intval($_POST['city']) : null,
        'town'      => isset($_POST['town']) ? $_POST['town'] : null,
        'category'  => isset($_POST['category']) ? intval($_POST['category']) : null,
        'pattern' => isset($_POST['pattern']) ? sanitize_text_field($_POST['pattern']) : null,
        'room'    => isset($_POST['room']) ? intval($_POST['room']) : null,
    );

    // Fetch the next filter data
    $result = emlak_real_estate_fetch_next_filter($current_filter, $filters);

    // Return the result as JSON
    wp_send_json($result);
    
}

// Register AJAX handler for fetching the next filter lands
function handle_fetch_next_filter_land() {
    // Get the current filter and other parameters from the AJAX request
    $current_filter = isset($_POST['currentFilter']) ? sanitize_text_field($_POST['currentFilter']) : '';
    $filters = array(
        'model'     => isset($_POST['model']) ? sanitize_text_field($_POST['model']) : 'resale',
        'city'      => isset($_POST['city']) ? intval($_POST['city']) : null,
        'town'      => isset($_POST['town']) ? $_POST['town'] : null
    );

    // // Fetch the next filter data
    $result = emlak_real_estate_fetch_next_filter($current_filter, $filters);

    // // Return the result as JSON
    wp_send_json($result);
}
add_action('wp_ajax_nopriv_fetch_land_filters', 'handle_fetch_next_filter_land');
add_action('wp_ajax_fetch_land_filters', 'handle_fetch_next_filter_land');

// Register AJAX handler for fetching the next filter lands
function handle_fetch_next_filter_project() {
    // Get the current filter and other parameters from the AJAX request
    $current_filter = isset($_POST['currentFilter']) ? sanitize_text_field($_POST['currentFilter']) : '';
    $filters = array(
        'model'     => isset($_POST['model']) ? sanitize_text_field($_POST['model']) : 'resale',
        'city'      => isset($_POST['city']) ? intval($_POST['city']) : null,
        'town'      => isset($_POST['town']) ? $_POST['town'] : null,
        'pattern' => isset($_POST['pattern']) ? sanitize_text_field($_POST['pattern']) : null,
        'room'    => isset($_POST['room']) ? intval($_POST['room']) : null
    );

    // // Fetch the next filter data
    $result = emlak_real_estate_fetch_next_filter($current_filter, $filters);

    // // Return the result as JSON
    wp_send_json($result);
}
add_action('wp_ajax_nopriv_fetch_project_filters', 'handle_fetch_next_filter_project');
add_action('wp_ajax_fetch_project_filters', 'handle_fetch_next_filter_project');

// Function to handle AJAX request
function handle_fetch_town() {
    if (!isset($_POST['city_id'])) {
        wp_send_json_error(['error' => 'City ID not provided']);
        wp_die();
    }
    
    if (!isset($_POST['model'])) {
        wp_send_json_error(['error' => 'Model not provided']);
        wp_die();
    }
    
    // Fetch town data based on city ID using your function
    $city_id = intval($_POST['city_id']);
    $model = $_POST['model'];
    $places = emlak_real_estate_fetch_places($city_id, $model);

    // Return the data as a JSON response
    if (!empty($places)) {
        wp_send_json_success($places);
    } else {
        wp_send_json_error(['error' => 'No places found']);
    }
    wp_die();
}

// Function to fetch Lands with optional filters
function emlak_real_estate_fetch_lands($current_page, $city = '', $town = '', $category = '', $min_price = '', $max_price = '', $keyword) {
    // Base API URL with current page
    $api_url = EMLAK_API_BASE_URL . 'lands?page=' . $current_page;
    $selected_currency = isset($_COOKIE['selected_currency']) ? $_COOKIE['selected_currency'] : 'USD';  
    
    // Add parameters if they have values
    $params = array();
    if (!empty($city)) {
        $params['city'] = str_replace('%20', '+', $city);
    }
    if (!empty($town)) {
        $params['town'] = str_replace('%20', '+', $town);
    }
    if (!empty($category)) {
        $params['category'] = str_replace('%20', '+', $category);
    }
    if (!empty($min_price)) {
        $params['min-price'] = $min_price;
    }
    if (!empty($max_price)) {
        $params['max-price'] = $max_price;
    }
    if (!empty($keyword)) {
        $params['q'] = str_replace('%20', '+', $keyword);
    }
    if (!empty($selected_currency)) {
        $params['cry'] = strtolower($selected_currency);
    }

    // Append parameters to API URL
    if (!empty($params)) {
        $api_url .= '&' . http_build_query($params);
    }

    // Fetch data from the API
    $response = wp_remote_get($api_url, array(
        'headers' => array(
            'Accept' => 'application/json',
            'access-key' => EMLAK_API_ACCESS_KEY, // Use your access key here
        ),
    ));

    // Handle error or return decoded response
    if (is_wp_error($response)) {
        return array('error' => 'Unable to fetch lands.');
    }
    
    $body = wp_remote_retrieve_body($response);
    // return $api_url;
    return json_decode($body, true); 
}

// Function to fetch land data by ID
function emlak_get_land_by_id($land_id) {
    $selected_currency = isset($_COOKIE['selected_currency']) ? $_COOKIE['selected_currency'] : 'USD';  
    // Base API URL with land ID
    $api_url = EMLAK_API_BASE_URL . 'lands/' . $land_id;

    // Add currency as a query parameter if selected
    if (!empty($selected_currency)) {
        $api_url = add_query_arg('cry', strtolower($selected_currency), $api_url);
    }

    $response = wp_remote_get( $api_url, array(
        'headers' => array(
            'Accept' => 'application/json',
            'access-key' => EMLAK_API_ACCESS_KEY,
        ),
    ));

    if ( is_wp_error( $response ) ) {
        return array('error' => 'Unable to fetch land.');
    }

    $body = wp_remote_retrieve_body( $response );
    return json_decode( $body, true );
}

// Function to fetch Projects
function emlak_real_estate_fetch_projects($current_page, $city = '', $town = '', $patterns = '', $rooms = '', $lounges = '', $min_price = '', $max_price = '', $keyword) {
    // Base API URL with current page
    $api_url = EMLAK_API_BASE_URL . 'projects?page=' . $current_page;
    $selected_currency = isset($_COOKIE['selected_currency']) ? $_COOKIE['selected_currency'] : 'USD';  

    // Add parameters if they have values
    $params = array();
    if (!empty($city)) {
        $params['city'] = str_replace('%20', '+', $city);
    }
    if (!empty($town)) {
        $params['town'] = str_replace('%20', '+', $town);
    }
    if (!empty($patterns)) {
        $params['pattern'] = str_replace('%20', '+', $patterns);
    }
    if (!empty($keyword)) {
        $params['q'] = str_replace('%20', '+', $keyword);
    }
    if (!empty($rooms)) {
        $params['room'] = $rooms;
    }
    if (!empty($lounges)) {
        $params['lounge'] = $lounges;
    }
    if (!empty($min_price)) {
        $params['min-price'] = $min_price;
    }
    if (!empty($max_price)) {
        $params['max-price'] = $max_price;
    }
    if (!empty($selected_currency)) {
        $params['cry'] = strtolower($selected_currency);
    }

    // Append parameters to API URL
    if (!empty($params)) {
        $api_url .= '&' . http_build_query($params);
    }

    // Fetch data from the API
    $response = wp_remote_get($api_url, array(
        'headers' => array(
            'Accept' => 'application/json',
            'access-key' => EMLAK_API_ACCESS_KEY, // Use your access key here
        ),
    ));

    // Handle error or return decoded response
    if (is_wp_error($response)) {
        return array('error' => 'Unable to fetch lands.');
    }

    $body = wp_remote_retrieve_body($response);
    return json_decode($body, true); 
}

// Function to fetch project data by ID
function emlak_get_project_by_id($project_id) {
    $selected_currency = isset($_COOKIE['selected_currency']) ? $_COOKIE['selected_currency'] : 'USD';  
    // Correct concatenation of the API URL
    $api_url = EMLAK_API_BASE_URL . 'projects/' . $project_id;
    
    // Add currency as a query parameter if selected
    if (!empty($selected_currency)) {
        $api_url = add_query_arg('cry', strtolower($selected_currency), $api_url);
    }
    
    $response = wp_remote_get( $api_url, array(
        'headers' => array(
            'Accept' => 'application/json',
            'access-key' => EMLAK_API_ACCESS_KEY,
        ),
    ));

    if ( is_wp_error( $response ) ) {
        return array('error' => 'Unable to fetch project.');
    }

    $body = wp_remote_retrieve_body( $response );
    return json_decode( $body, true ); 
}

// Function to fetch properties
function emlak_real_estate_fetch_properties($current_page, $city = '', $town = '', $category = '', $patterns = '', $rooms = '', $lounges = '', $min_price = '', $max_price = '', $keyword) {
    $selected_currency = isset($_COOKIE['selected_currency']) ? $_COOKIE['selected_currency'] : 'USD';  
    // Base API URL with current page
    $api_url = EMLAK_API_BASE_URL . 'resales?page=' . $current_page;

    // Add parameters if they have values
    $params = array();
    if (!empty($city)) {
        $params['city'] = str_replace('%20', '+', $city);
    }
    if (!empty($town)) {
        $params['town'] = str_replace('%20', '+', $town);
    }
    if (!empty($keyword)) {
        $params['q'] = str_replace('%20', '+', $keyword);
    }
    if (!empty($category)) {
        $params['category'] = str_replace('%20', '+', $category);
    }
    if (!empty($patterns)) {
        $params['pattern'] = str_replace('%20', '+', $patterns);
    }
    if (!empty($rooms)) {
        $params['room'] = $rooms;
    }
    if (!empty($lounges)) {
        $params['lounge'] = $lounges;
    }
    if (!empty($min_price)) {
        $params['min-price'] = $min_price;
    }
    if (!empty($max_price)) {
        $params['max-price'] = $max_price;
    }
    if (!empty($selected_currency)) {
        $params['cry'] = strtolower($selected_currency);
    }

    // Append parameters to API URL
    if (!empty($params)) {
        $api_url .= '&' . http_build_query($params);
    }

    // Fetch data from the API
    $response = wp_remote_get($api_url, array(
        'headers' => array(
            'Accept' => 'application/json',
            'access-key' => EMLAK_API_ACCESS_KEY, // Use your access key here
        ),
    ));

    // Handle error or return decoded response
    if (is_wp_error($response)) {
        return array('error' => 'Unable to fetch lands.');
    }

    $body = wp_remote_retrieve_body($response);
    return json_decode($body, true); 
}

// Function to fetch property data by ID
function emlak_get_property_by_id($property_id) {
     $selected_currency = isset($_COOKIE['selected_currency']) ? $_COOKIE['selected_currency'] : 'USD';  
    // Correct concatenation of the API URL
    $api_url = EMLAK_API_BASE_URL . 'resales/' . $property_id;
    
    // Add currency as a query parameter if selected
    if (!empty($selected_currency)) {
        $api_url = add_query_arg('cry', strtolower($selected_currency), $api_url);
    }

    $response = wp_remote_get( $api_url, array(
        'headers' => array(
            'Accept' => 'application/json',
            'access-key' => EMLAK_API_ACCESS_KEY,
        ),
    ));

    if ( is_wp_error( $response ) ) {
        return array('error' => 'Unable to fetch property.');
    }

    $body = wp_remote_retrieve_body( $response );
    return json_decode( $body, true ); 
}
?>
