<?php

// Exit if accessed directly.
if (!defined('ABSPATH')) exit;

/**
 * Enqueue necessary scripts.
 */
function custom_verification_enqueue_scripts() {
    wp_enqueue_script('jquery');
}

/**
 * Activation hook: Initialize plugin settings.
 */
function custom_verification_activate() {
    // Optionally initialize or set any options on activation if needed.
}

/**
 * Deactivation hook: Clean up options.
 */
function custom_verification_deactivate() {
    delete_option('custom_verified_email');
    delete_option('custom_verified_secret_key');
    delete_option('custom_verified_token');
    delete_option('custom_emlak_token_access');
}

/**
 * Add plugin settings page to admin menu.
 */
function custom_verification_add_admin_menu() {
    add_menu_page(
        'Emlak Verification Settings',
        'Emlak Account Verification',
        'manage_options',
        'custom-verification',
        'custom_verification_settings_page',
        'dashicons-lock',
        100
    );
}

/**
 * Display plugin settings page.
 */
function custom_verification_settings_page() {
    ?>
    <div class="wrap">
        <h1>Custom Verification Settings</h1>
        <?php
        $message = '';

        // Handle form submissions
        custom_verification_handle_first_layer($message);
        custom_verification_handle_second_layer($message);

        // Display message if any
        if (!empty($message)) {
            echo '<div class="notice notice-info is-dismissible">' . esc_html($message) . '</div>';
        }

        // Show first layer form if not verified
        if (!get_option('custom_verified_token')) : ?>
            <form method="post" action="">
                <h2>Layer 1: First API Verification</h2>
                <label>Email: <input type="email" name="email" required></label><br>
                <label>Secret Key: <input type="text" name="secret_key" required></label><br>
                <label>Token: <input type="text" name="token" required></label><br>
                <input type="submit" name="submit_first_layer" value="Verify First Layer">
            </form>
        <?php elseif (get_option('custom_verified_token') && !get_option('custom_emlak_token_access')) : ?>
            <form method="post" action="">
                <h2>Layer 2: Emlak API Verification</h2>
                <label>emlak_token_access: <input type="text" name="emlak_token" required></label><br>
                <input type="submit" name="submit_second_layer" value="Verify Second Layer">
            </form>
        <?php elseif (get_option('custom_emlak_token_access')) : ?>
            <h2>You are authorized to use the plugin!</h2>
        <?php endif; ?>
    </div>
    <?php
}

/**
 * Handle First Layer API Verification.
 */
function custom_verification_handle_first_layer(&$message) {
    if (isset($_POST['submit_first_layer'])) {
        $email = sanitize_email($_POST['email']);
        $secret_key = sanitize_text_field($_POST['secret_key']);
        $token = sanitize_text_field($_POST['token']);

        $api_url = 'https://manage.hasanalbaba.me/wp-json/custom/v1/verify-key';
        $response = wp_remote_post($api_url, array(
            'method'    => 'POST',
            'body'      => json_encode(array(
                'email'      => $email,
                'secret_key' => $secret_key,
                'token'      => $token,
            )),
            'headers'   => array(
                'Content-Type' => 'application/json',
            ),
        ));

        // Check for errors in the response
        if (is_wp_error($response)) {
            $message = 'There was an error communicating with the API.';
        } else {
            // Decode the response
            $body = json_decode(wp_remote_retrieve_body($response), true);
            
            // Check if verified
            if (isset($body['verified']) && $body['verified'] === true) {
                update_option('custom_verified_email', $email);
                update_option('custom_verified_secret_key', $secret_key);
                update_option('custom_verified_token', $token);
                $message = 'First layer verified successfully! You can now proceed to the second layer.';
            } else {
                // Handle different error responses
                if (isset($body['code']) && $body['code'] === 'invalid_token') {
                    $message = 'Invalid or expired token.';
                } else {
                    $message = 'Verification failed. Please check your credentials.';
                }
            }
        }
    }
}

/**
 * Handle Second Layer API Verification.
 */
function custom_verification_handle_second_layer(&$message) {
    if (isset($_POST['submit_second_layer'])) {
        $emlak_token = sanitize_text_field($_POST['emlak_token']);

        $api_url = 'https://www.emlakplatform.com.tr/api/v1/activate';
        $response = wp_remote_get($api_url, array(
            'headers' => array(
                'access-key' => $emlak_token,
            ),
        ));

        if (wp_remote_retrieve_response_code($response) == 200) {
            update_option('custom_emlak_token_access', $emlak_token);
            $message = 'Second Layer Verification successful! You are now authorized to use the plugin.';
        } else {
            $message = 'Verification failed. Please check your credentials.';
        }
    }
}
