<?php
/*
Plugin Name: Emlak Real Estate
Description: A plugin for managing properties, lands, and resales.
Version: 1.0
Author: Hasan Al Baba & Samah Basheer
Author URI: https://hasanalbaba.mebox
*/

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

function emlak_real_estate_enqueue_scripts() {
    // Enqueue the custom scripts
    wp_enqueue_script( 'fancybox-scripts', plugin_dir_url( __FILE__ ) . 'assets/js/fancybox.umd.js', array('jquery'), '1.0.0', true );
    wp_enqueue_script( 'select2-scripts', plugin_dir_url( __FILE__ ) . 'assets/js/select2.min.js', array('jquery'), '1.0.0', true );
    wp_enqueue_script( 'custom-scripts', plugin_dir_url( __FILE__ ) . 'assets/js/main.js', array('jquery'), time(), true );

    // Enqueue the custom styles
    wp_enqueue_style( 'fontawesome-styles', plugin_dir_url( __FILE__ ) . 'assets/css/all.min.css', array(), '1.0.1', 'all' );
    wp_enqueue_style( 'custom-styles', plugin_dir_url( __FILE__ ) . 'assets/css/style.css', array(), time(), 'all' );
    wp_enqueue_style( 'fancybox-styles', plugin_dir_url( __FILE__ ) . 'assets/css/fancybox.css', array(), '1.0.0', 'all' );
    wp_enqueue_style( 'select2-styles', plugin_dir_url( __FILE__ ) . 'assets/css/select2.min.css', array(), '1.0.0', 'all' );

    // Localize the script to pass ajax_url to JavaScript
    wp_localize_script('custom-scripts', 'emlak_ajax', array(
        'ajax_url' => admin_url('admin-ajax.php')
    ));

    // Enqueue Bootstrap styles and scripts
    wp_enqueue_style( 'bootstrap-styles', plugin_dir_url( __FILE__ ) . 'assets/bootstrap/css/bootstrap.min.css' );
    wp_enqueue_script( 'bootstrap-scripts', plugin_dir_url( __FILE__ ) . 'assets/bootstrap/js/bootstrap.bundle.min.js', array('jquery'), time(), true );
}
// Enqueue plugin scripts
add_action( 'wp_enqueue_scripts', 'emlak_real_estate_enqueue_scripts' );
// add_action( 'admin_enqueue_scripts', 'emlak_real_estate_enqueue_scripts' );


require_once plugin_dir_path(__FILE__) . 'includes/verification-handler.php';
require_once plugin_dir_path(__FILE__) . 'includes/api-handler.php';
require_once plugin_dir_path(__FILE__) . 'currency.php';

$first_layer_verified = get_option('custom_verified_token');
$second_layer_verified = get_option('custom_emlak_token_access');

// Activation and Deactivation hooks.
register_activation_hook(__FILE__, 'custom_verification_activate');
register_deactivation_hook(__FILE__, 'custom_verification_deactivate');

// Enqueue scripts for admin
add_action('admin_enqueue_scripts', 'custom_verification_enqueue_scripts');

// Add admin menu item
add_action('admin_menu', 'custom_verification_add_admin_menu');


// Hook into plugin deactivation
register_deactivation_hook( __FILE__, 'emlak_real_estate_remove_pages' );
function emlak_real_estate_remove_pages() {
    $page_titles = [
        'Resale',
        'Single Resale',
        'Lands',
        'Single Land',
        'Projects',
        'Single Project',
    ];

    foreach ( $page_titles as $title ) {
        $page = get_page_by_title( $title );
        
        if ( $page ) {
            wp_delete_post( $page->ID, true );
        }
    }
}

// Hook to create pages when the plugin is activated
function emlak_real_estate_create_pages() {
    $pages = [
        'Resale' => 'Here you can list all properties',
        'Single Resale' => 'Here you can list single property',
        'Lands'      => 'Here you can list all lands',
        'Single Land'      => 'Here you can list single land',
        'Projects'  => 'Here you can list all projects',
        'Single Project' => 'Here you can list single project'
    ];

    foreach ( $pages as $title => $content ) {
        // Check if the page already exists
        $page = get_page_by_title( $title );

        if ( ! $page ) {
            // Create the page
            $page_id = wp_insert_post([
                'post_title'    => $title,
                'post_content'  => $content,
                'post_status'   => 'publish',
                'post_type'     => 'page'
            ]);
        }
    }
}
// Hook into plugin activation
register_activation_hook( __FILE__, 'emlak_real_estate_create_pages' );
    
add_filter( 'template_include', 'emlak_real_estate_load_template' );
// Function to check if it's the Lands Page or Single Land Page and assign the correct template
function emlak_real_estate_load_template( $template ) {
    // Get the current post object
    global $post;
    
    require_once plugin_dir_path(__FILE__) . 'templates/pagination.php';

    // Define the paths to your custom templates inside the plugin's folder
    $lands_template = plugin_dir_path( __FILE__ ) . 'templates/land/page-lands.php';
    $single_land_template = plugin_dir_path( __FILE__ ) . 'templates/land/single-land-template.php';
    $projects_template = plugin_dir_path( __FILE__ ) . 'templates/projects/projects-page.php';
    $single_project_template = plugin_dir_path( __FILE__ ) . 'templates/projects/single-project-template.php';
    $properties_template = plugin_dir_path( __FILE__ ) . 'templates/properties/properties-page.php';
    $single_property_template = plugin_dir_path( __FILE__ ) . 'templates/properties/single-property-template.php';

    // Check if we are on the "Lands Page" and apply the custom template
    if ( is_page() && $post->post_title == 'Lands' ) {
        // If the template exists, use it
        if ( file_exists( $lands_template ) ) {
            return $lands_template;
        }
    }

    // Check if it's the "Single Land" page with the "land_id" in the URL
    if ( is_page() && $post->post_title == 'Single Land' && isset($_GET['land_id']) && !empty($_GET['land_id']) ) {
        // Ensure the "land_id" parameter is present in the URL and use the single land template
        if ( file_exists( $single_land_template ) ) {
            return $single_land_template;
        }
    }
    
     // Check if we are on the "Projects Page" and apply the custom template
    if ( is_page() && $post->post_title == 'Projects' ) {
        // If the template exists, use it
        if ( file_exists( $projects_template ) ) {
            return $projects_template;
        }
    }
    
    // Check if it's the "Single Project Page" page with the "land_id" in the URL
    if ( is_page() && $post->post_title == 'Single Project' && isset($_GET['project_id']) && !empty($_GET['project_id']) ) {
        // Ensure the "land_id" parameter is present in the URL and use the single land template
        if ( file_exists( $single_project_template ) ) {
            return $single_project_template;
        }
    }
    
        // Check if we are on the "properties Page" and apply the custom template
    if ( is_page() && $post->post_title == 'Resale' ) {
        // If the template exists, use it
        if ( file_exists( $properties_template ) ) {
            return $properties_template;
        }
    }
    
    // Check if it's the "Single property Page" page with the "land_id" in the URL
    if ( is_page() && $post->post_title == 'Single Resale' && isset($_GET['property_id']) && !empty($_GET['property_id']) ) {
        // Ensure the "land_id" parameter is present in the URL and use the single land template
        if ( file_exists( $single_property_template ) ) {
            return $single_property_template;
        }
    }

    // Otherwise, return the default template
    return $template;
}

