<?php
function render_land_filter() {
    // Define the options for the dropdowns
    $cities = emlak_real_estate_fetch_cities('land');
    $categories = [];

    ob_start();
    ?>
    <div class="container-fluid primary-section">
        <div class="container search-bar">
            <div class="row">
                <div class="col-12">
                    <label><small>Search with Keyword</small></label>
                </div>
                <div class="col-12 d-flex my-0">
                    <input type="text" class="form-control search-keyword" id="keyword" placeholder="Search by keyword" aria-label="Search by keyword">
                    <button class="btn btn-primary search-btn" onclick="updateURL()">
                        <i class="fa-solid fa-magnifying-glass"></i>
                    </button>
                </div>
            </div>
            <div class="row">
                <div class="col-12 text-center mt-3">
                    <button class="filters-btn" type="button" data-bs-toggle="collapse" data-bs-target="#moreFilters" aria-expanded="false" aria-controls="moreFilters">
                        Open Advanced Filters <i class="fa-solid fa-sliders"></i>
                    </button>
                </div>
            </div>
            <div class="row collapse" id="moreFilters">
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>City</small></label>
                    <select class="form-select select2" id="city" placeholder="City">
                        <option value="" selected>Select City</option>
                        <?php foreach ($cities as $key => $city) : ?>
                            <option value="<?php echo $key; ?>"><?php echo $city; ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>Town</small></label>
                    <select class="form-select select2" id="town" placeholder="Town">
                        <option value="" selected>Select Town</option>
                        <!-- Town options will be populated dynamically -->
                    </select>
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>Category</small></label>
                    <select class="form-select select2" id="category" placeholder="Category">
                        <option value="" selected>Select Category</option>
                        <?php foreach ($categories as $key => $category) : ?>
                            <option value="<?php echo $category; ?>"><?php echo $category; ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>Min Price / m²</small></label>
                    <input type="number" class="form-control" placeholder="Min Price / m²" id="minPrice">
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>Max Price / m²</small></label>
                    <input type="number" class="form-control" placeholder="Max Price / m²" id="maxPrice">
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3 d-flex align-items-end">
                    <button class="submit-btn" type="button" onclick="updateURL()">
                        Search
                    </button>
                </div>
            </div>
        </div>
    </div>
    
    <script>
        const $ = jQuery;
        jQuery(document).ready(function($) {

            // Function to fetch places based on selected city
            async function fetchPlaces(cityId, model) {
                try {
                    const response = await $.ajax({
                        url: emlak_ajax.ajax_url,
                        method: 'POST',
                        data: {
                            action: 'fetch_town',
                            city_id: cityId,
                            model: model
                        }
                    });
                    var placesSelect = $('#town');
                    placesSelect.empty();
            
                    if (response.success) {
                        // Populate places into the select dropdown
                        placesSelect.append(new Option('Select Town', ''));
                        response.data.forEach(function(place) {
                            placesSelect.append(new Option(place.title, place.id));
                        });
                    } else {
                        console.error(response.data.error || 'Error fetching places.');
                    }
                } catch (error) {
                    console.error('Failed to fetch places.', error);
                }
            }
            
            // Event listener for when a city is selected
            $('#city').change(async function () {
                var selectedCityId = $(this).val();
                
                // Check if #category or #town has a selected option (not the default empty option)
                if ($('#category').val() || $('#town').val()) {
                    // If they have selected options, clear them and set the default option
                    $("#category").empty().append(new Option('Select Category', ''));
                    $("#town").empty().append(new Option('Select Town', ''));
                }
            
                // Fetch places based on the selected city
                if (selectedCityId) {
                    await fetchPlaces(selectedCityId, 'land');
                }
            });

            function fetchNextFilterLands(currentFilter, filters) {
            
                $.ajax({
                    url: emlak_ajax.ajax_url,
                    type: 'POST',
                    data: {
                        action: 'fetch_land_filters',
                        currentFilter: currentFilter,
                        model: filters.model,
                        city: filters.city || '',
                        town: filters.town || ''
                    },
                    dataType: 'json',
                    success: function (response) {
                        if (response.error) {
                            console.error('Error: ' + response.error);
                        } else {
                            if (currentFilter === 'town') {
                                const categorySelect = $("#category");
                                categorySelect.empty();
                                categorySelect.append(new Option('Select Category', ''));
            
                                // Check if response is an array
                                if (Array.isArray(response) && response.length > 0) {
                                    response.forEach(function (category) {
                                        categorySelect.append(new Option(category.title, category.id));
                                    });
                                } else if (typeof response === 'object' && response !== null) {
                                    // If response is a single object
                                    if (response.title && response.id) {
                                        categorySelect.append(new Option(response.title, response.id));
                                    } else {
                                        console.warn('Object does not have the expected properties.');
                                    }
                                } else {
                                    console.warn('No data available or not in the expected format.');
                                }
                            }
                        }
                    },
                    error: function () {
                        console.error('Error fetching next filter.');
                    }
                });
            }
            
            // Function to determine which filter to call next based on the previous selection
            $('#town').change(function () {
                const filters = {
                    model: 'land',
                    city: $('#city').val(),
                    town: $('#town').val()
                };
            
                // Check the current state of filters to decide which one to fetch next
                if (filters.city && filters.town) {
                    // If city and town are selected but category is not, fetch category options
                    fetchNextFilterLands('town', filters);
                }
            });
        
            // Function to get URL parameters
            function getURLParameter(name) {
                const urlParams = new URLSearchParams(window.location.search);
                return urlParams.get(name) || '';
            }
            
            // Updated window.onload function with loading overlay
            window.onload = async function() {
                // Get parameters from URL
                const city = getURLParameter('city');
                const town = getURLParameter('town');
                const category = getURLParameter('category');
                const minPrice = getURLParameter('min-price');
                const maxPrice = getURLParameter('max-price');
                const keyword = getURLParameter('q');
            
                try {
                    // If city parameter exists, select city and fetch towns
                    if (city) {
                        await fetchPlaces(city, 'land');;
                    }
            
                    // If town parameter exists, select town and fetch categories
                    if (town) {
                        await fetchNextFilterLands('town', {
                            model: 'land',
                            city: city,
                            town: town
                        });
                    }
                    
                    setTimeout(() => {
                        jQuery('#city').val(city).trigger('change.select2');
                        jQuery('#town').val(town).trigger('change.select2');
                        jQuery('#category').val(category).trigger('change.select2');
                    }, 10000);
                    
                    
                    
                    // Set values for regular text/number inputs if parameters exist
                    if (minPrice) document.getElementById('minPrice').value = minPrice;
                    if (maxPrice) document.getElementById('maxPrice').value = maxPrice;
                    if (keyword) document.getElementById('keyword').value = keyword;
            
                } catch (error) {
                    console.error('Error during the fetch process:', error);
                }
            };

        });
        
        function updateURL() {
            const city = document.getElementById('city').value;
            const town = document.getElementById('town').value;
            const category = document.getElementById('category').value;
            const minPrice = document.getElementById('minPrice').value;
            const maxPrice = document.getElementById('maxPrice').value;
            const keyword = document.getElementById('keyword').value;
    
            let url = '/lands?';
            if (city) url += '&city=' + encodeURIComponent(city);
            if (town) url += '&town=' + encodeURIComponent(town);
            if (category) url += '&category=' + encodeURIComponent(category);
            if (minPrice) url += '&min-price=' + encodeURIComponent(minPrice);
            if (maxPrice) url += '&max-price=' + encodeURIComponent(maxPrice);
            if (keyword) url += '&q=' + encodeURIComponent(keyword);
    
            window.location.href = url;
        }
    </script>

    <?php
    return ob_get_clean();
}


?>
