<?php

function generate_pagination_links($current_page, $last_page, $base_url, $filters) {
    // Build the query string for filters, excluding empty parameters
    $filtered_params = array_filter($filters, function($value) {
        return !empty($value);
    });

    // Create the query string only with non-empty parameters
    $query_string = http_build_query($filtered_params);

    // Set a fixed range of pages to display around the current page
    $range = 3;  // Number of pages to show before and after the current page

    // Start pagination output
    $pagination_html = '<div class="container"><div class="row"><nav aria-label="Page navigation">';
    $pagination_html .= '<ul class="pagination justify-content-center pt-3 pb-4">';

    // Previous Page Link
    if ($current_page > 1) {
        $prev_page = $current_page - 1;
        $pagination_html .= '<li class="page-item"><a class="page-link" href="' . $base_url . '?pg=' . $prev_page . ($query_string ? '&' . $query_string : '') . '">Previous</a></li>';
    }

    // Show first page and "..." if current page is outside the initial range
    if ($current_page > $range + 1) {
        $pagination_html .= '<li class="page-item"><a class="page-link" href="' . $base_url . '?pg=1' . ($query_string ? '&' . $query_string : '') . '">1</a></li>';
        $pagination_html .= '<li class="page-item disabled"><span class="page-link">...</span></li>';
    }

    // Display page numbers within the fixed range
    for ($i = max(1, $current_page - $range); $i <= min($last_page, $current_page + $range); $i++) {
        $active_class = ($i === $current_page) ? 'active' : '';
        $pagination_html .= '<li class="page-item ' . $active_class . '"><a class="page-link" href="' . $base_url . '?pg=' . $i . ($query_string ? '&' . $query_string : '') . '">' . $i . '</a></li>';
    }

    // Show "..." and last page if current page is outside the final range
    if ($current_page < $last_page - $range) {
        $pagination_html .= '<li class="page-item disabled"><span class="page-link">...</span></li>';
        $pagination_html .= '<li class="page-item"><a class="page-link" href="' . $base_url . '?pg=' . $last_page . ($query_string ? '&' . $query_string : '') . '">' . $last_page . '</a></li>';
    }

    // Next Page Link
    if ($current_page < $last_page) {
        $next_page = $current_page + 1;
        $pagination_html .= '<li class="page-item"><a class="page-link" href="' . $base_url . '?pg=' . $next_page . ($query_string ? '&' . $query_string : '') . '">Next</a></li>';
    }

    $pagination_html .= '</ul>';
    $pagination_html .= '</nav></div></div>';

    // Return the pagination HTML
    return $pagination_html;
}


function build_url($base_url, $page_number, $filters) {
    $url = $base_url . '?pg=' . $page_number;

    // Append filters to the URL
    foreach ($filters as $key => $value) {
        if (!empty($value)) {
            $url .= '&' . urlencode($key) . '=' . urlencode($value);
        }
    }

    return $url;
}




// function generate_pagination_links($current_page, $last_page, $base_url) {
//     // Set a fixed range of pages to display around the current page
//     $range = 3;  // Number of pages to show before and after the current page

//     // Start pagination output
//     $pagination_html = '<div class="container"><div class="row"><nav aria-label="Page navigation">';
//     $pagination_html .= '<ul class="pagination justify-content-center pt-3 pb-4">';

//     // Previous Page Link
//     if ($current_page > 1) {
//         $prev_page = $current_page - 1;
//         $pagination_html .= '<li class="page-item"><a class="page-link" href="' . $base_url . '?pg=' . $prev_page . '">Previous</a></li>';
//     }

//     // Show first page and "..." if current page is outside the initial range
//     if ($current_page > $range + 1) {
//         $pagination_html .= '<li class="page-item"><a class="page-link" href="' . $base_url . '?pg=1">1</a></li>';
//         $pagination_html .= '<li class="page-item disabled"><span class="page-link">...</span></li>';
//     }

//     // Display page numbers within the fixed range
//     for ($i = max(1, $current_page - $range); $i <= min($last_page, $current_page + $range); $i++) {
//         $active_class = ($i === $current_page) ? 'active' : '';
//         $pagination_html .= '<li class="page-item ' . $active_class . '"><a class="page-link" href="' . $base_url . '?pg=' . $i . '">' . $i . '</a></li>';
//     }

//     // Show "..." and last page if current page is outside the final range
//     if ($current_page < $last_page - $range) {
//         $pagination_html .= '<li class="page-item disabled"><span class="page-link">...</span></li>';
//         $pagination_html .= '<li class="page-item"><a class="page-link" href="' . $base_url . '?pg=' . $last_page . '">' . $last_page . '</a></li>';
//     }

//     // Next Page Link
//     if ($current_page < $last_page) {
//         $next_page = $current_page + 1;
//         $pagination_html .= '<li class="page-item"><a class="page-link" href="' . $base_url . '?pg=' . $next_page . '">Next</a></li>';
//     }

//     $pagination_html .= '</ul>';
//     $pagination_html .= '</nav></div></div>';

//     // Return the pagination HTML
//     return $pagination_html;
// }
