<?php

function load_projects_template($project_data) {
    $selected_currency = isset($_COOKIE['selected_currency']) ? $_COOKIE['selected_currency'] : 'USD'; 
    $price = number_format($project_data['disp_price'], 2, '.', ',');
    ?>
      <div class="col-lg-4 col-md-6 col-sm-12 mb-4">
        <div class="card custom-card h-100">
          <div class="image-container">
            <a href="/single-project/?project_id=<?php echo esc_html($project_data['slug']); ?>">
              <img src="<?php echo esc_url($project_data['main_pic']); ?>" class="card-img-top" alt="<?php echo esc_attr($project_data['title']); ?>">
            </a>
          </div>
          <div class="card-body">
            <div class="upper-part">
                <div class="badge-container">
                    <?php if ($project_data['available'] == 0): ?>
                        <span class="badge sold-badge">Sold</span>
                    <?php endif; ?>
                    <?php if ($project_data['extra_attributes']['exclusive'] == 1): ?>
                        <span class="badge exclusive-badge">Exclusive</span>
                    <?php endif; ?>
                    <?php if ($project_data['extra_attributes']['pending'] == 1): ?>
                        <span class="badge pending-badge">Pending</span>
                    <?php endif; ?>
                    <?php if (!empty($project_data['discount_percentage'])) : ?>
                        <span class="badge secondary-badge">Discount <?php echo esc_html($project_data['discount_percentage']); ?>%</span>
                    <?php endif; ?>
                    <span class="badge primary-badge"><?php echo esc_html($project_data['code']); ?></span>
                </div>
                <?php
                $payments = isset($project_data['payments']) ? intval($project_data['payments']) : 0;
                $downpayment = isset($project_data['downpayment']) ? intval($project_data['downpayment']) : 0;
                
                if ($payments === 0) {
                    ?>
                    <div class="payment-terms d-flex justify-content-center">
                        <div class="small-text"><span>Payment Method: Cash</span></div>
                    </div>
                    <?php
                } else {
                    ?>
                    <div class="payment-terms d-flex justify-content-between">
                        <div class="small-text"><span>Installments</span> <strong><?php echo esc_html($payments); ?></strong> <span>Month</span></div>
                        <div class="line">|</div>
                        <div class="small-text"><span>Down payment</span> <strong><?php echo esc_html($downpayment); ?>%</strong></div>
                    </div>
                    <?php
                }
                ?>
              <hr class="divider">
              <h3 class="card-price" dir="ltr">
                <span><?php echo $price; ?>
                  <small class="text-uppercase currency"><?php echo $selected_currency; ?></small>
                </span>
              </h3>
              <h6 class="card-title">
                <a href="/single-project/?project_id=<?php echo esc_html($project_data['slug']); ?>" class="card-title-link verified prt-link-detail">
                  <?php echo esc_html($project_data['title']); ?>
                </a>
              </h6>
              <p class="my-0 custom-excerpt"><?php echo esc_html($project_data['description']); ?></p>
            </div>
            <div class="lower-part">
              <hr class="divider">
              <div class="location-area">
                <span class="location">
                  <span class="icon">
                    <i class="fa-solid fa-location-dot"></i>
                  </span>
                  <?php echo esc_html($project_data['location_text']['title']); ?>
                </span>
                <span class="area">
                  <span class="icon">
                    <i class="fa-solid fa-calendar-days"></i>
                  </span>
                  <?php echo esc_html($project_data['delivery_date']); ?>
                </span>
              </div>
              <hr class="divider">
              <a href="/single-project/?project_id=<?php echo esc_html($project_data['slug']); ?>" class="btn btn-primary">View Details</a>
            </div>
          </div>
        </div>
      </div>
    <?php
}
require_once plugin_dir_path(__FILE__) . 'project-filters.php';
require_once plugin_dir_path(__FILE__) . '../sort-box.php';

// Fetch the Projects Page ID dynamically
$projects_page = get_page_by_title( 'Projects' );
$project_page_id = $projects_page ? $projects_page->ID : null;

// Get the current page number from the URL or default to 1
$current_page = isset($_GET['pg']) ? (int) $_GET['pg'] : 1;

// Check for additional parameters in the URL
$keyword = isset($_GET['q']) ? sanitize_text_field($_GET['q']) : '';
$city = isset($_GET['city']) ? sanitize_text_field($_GET['city']) : '';
$town = isset($_GET['town']) ? sanitize_text_field($_GET['town']) : '';
$patterns = isset($_GET['patterns']) ? sanitize_text_field($_GET['patterns']) : '';
$rooms = isset($_GET['rooms']) ? sanitize_text_field($_GET['rooms']) : '';
$lounges = isset($_GET['lounges']) ? sanitize_text_field($_GET['lounges']) : '';
$min_price = isset($_GET['min-price']) ? (int)$_GET['min-price'] : '';
$max_price = isset($_GET['max-price']) ? (int)$_GET['max-price'] : '';

// Fetch data from the API with page and optional filter parameters
$projects_data = emlak_real_estate_fetch_projects($current_page, $city, $town, $patterns, $rooms, $lounges, $min_price, $max_price, $keyword);

// Fetch data from the API with the page parameter
// $projects_data = emlak_real_estate_fetch_projects($current_page);

// Total number of pages (from API response)
$last_page = isset($projects_data['last_page']) ? (int) $projects_data['last_page'] : 1;

get_header();  // Include the header

// Check if the current page is the "Lands Page"
if (is_page($project_page_id)) {
    echo render_project_filter();
    // Display lands if available
    if (!empty($projects_data['data'])) {
        echo getInfoBox($projects_data['total'], $projects_page->post_title);
        echo '<div class="projects-container container mt-5"><div class="row">';
        foreach ($projects_data['data'] as $project) {
            // Call the function to load the template with the land data
            load_projects_template($project);
        }
        echo '</div></div>';
        // Prepare filters as an associative array
        $filters = [
          'city' => $city,
          'town' => $town,
          'patterns' => $patterns,
          'rooms' => $rooms,
          'lounges' => $lounges,
          'min-price' => $min_price,
          'max-price' => $max_price,
          'q' => $keyword
        ];

      // Use the pagination function
      echo generate_pagination_links($current_page, $last_page, '/projects', $filters);
    } else {
        echo '<div class="container empty-loop mt-5"><div class="row">';
        echo '<p>No Projects available at the moment.</p>';
        echo '</div></div>';
    }
    
} else {
    // Default behavior for other pages/posts
    if (have_posts()) {
        while (have_posts()) {
            the_post();
            the_content();
        }
    }
}

get_footer();  // Include the footer
