<?php

// Get the project_id from the URL parameter using $_GET without casting it to an integer
$project_id = isset($_GET['project_id']) ? sanitize_text_field($_GET['project_id']) : '';
$project_data = emlak_get_project_by_id($project_id);

function load_single_project_template($project_data){
    $selected_currency = isset($_COOKIE['selected_currency']) ? $_COOKIE['selected_currency'] : 'USD'; 
    $price = number_format($project_data['disp_price'], 2, '.', ',');
    $area = number_format($project_data['extra_attributes']['project_area'], 0, '.', ',');
    ?>
    <div class="container-fluid primary-section">
        <div class="container px-0">
            <div class="row align-items-center">
                <div class="col-lg-9 col-md-8 col-sm-12">
                    <h1 class="mx-0 my-0"><?php echo $project_data['title']; ?></h1>
                    <p class="pt-2"><?php echo $project_data['description']; ?></p>
                </div>
                <div class="col-lg-3 col-md-4 col-sm-12">
                    <p class="my-0 text-lg-end text-md-end">Starts at</p>
                    <h1 class="my-0 text-lg-end text-md-end"><?php echo $price; ?> <?php echo $selected_currency; ?></h1>
                </div>
                <?php if (!empty($project_data['discount_percentage'])) : ?>
                    <div class="badge-box">
                        <p class="inner-badge discount-badge mb-0">
                            Discounts <?php echo esc_html($project_data['discount_percentage']); ?>%
                        </p>
                        <?php if ($project_data['available'] == 0): ?>
                            <p class="inner-badge sold-badge mb-0">Sold</p>
                        <?php endif; ?>
                        <?php if ($project_data['extra_attributes']['exclusive'] == 1): ?>
                            <p class="inner-badge exclusive-badge mb-0">Exclusive</p>
                        <?php endif; ?>
                        <?php if ($project_data['extra_attributes']['pending'] == 1): ?>
                            <p class="inner-badge pending-badge mb-0">Pending</p>
                        <?php endif; ?>
                    </div>
                <?php endif; ?>
            </div>
        </div>
    </div>

    <div class="container-fluid single-land px-0">
        <div class="container pt-5 pb-5">
            <div class="row">
                <div class="col-lg-8 col-md-12 col-sm-12">
                    <!-- Carousel for images with Fancybox -->
                    <div id="landCarousel" class="carousel slide" data-bs-ride="carousel">
                        <div class="carousel-inner">
                            <?php 
                            // Assuming $project_data['pics'] contains the array of image URLs
                            $pics = $project_data['pics'];
                            foreach ($pics as $index => $pic) {
                                // Check if it's the first item to set it as active
                                $activeClass = ($index === 0) ? 'active' : '';
                                echo '<div class="carousel-item ' . $activeClass . '">';
                                echo '<a href="' . $pic . '" data-fancybox="landImages">';
                                echo '<img src="' . $pic . '" class="d-block w-100" alt="Land Image ' . ($index + 1) . '">';
                                echo '</a>';
                                echo '</div>';
                            }
                            ?>
                        </div>
                        <button class="carousel-control-prev" type="button" data-bs-target="#landCarousel" data-bs-slide="prev">
                            <span class="carousel-control-prev-icon" aria-hidden="true"></span>
                            <span class="visually-hidden">Previous</span>
                        </button>
                        <button class="carousel-control-next" type="button" data-bs-target="#landCarousel" data-bs-slide="next">
                            <span class="carousel-control-next-icon" aria-hidden="true"></span>
                            <span class="visually-hidden">Next</span>
                        </button>
                    </div>

                    <div class="details-box">
                        <div class="container p-0">
                            <div class="row g-3">
                                <div class="col-lg-3 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p><strong>Location</strong></p>
                                        </div>
                                        <div class="pb-2">
                                            <i class="fa-solid fa-location-crosshairs"></i>
                                        </div>
                                        <div>
                                            <p><?php echo $project_data['location_text']['title']; ?></p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-3 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p><strong>Payment Method</strong></p>
                                        </div>
                                        <div class="pb-2">
                                            <i class="fa-solid fa-money-bill-1-wave"></i>
                                        </div>
                                        <div>
                                            <?php if (empty($project_data['payments'])) : ?>
                                                <p>Cash</p>
                                            <?php else : ?>
                                                <div class="d-flex w-100 instalments-box">
                                                    <div class="w-50">
                                                        <span> <strong><?php echo $project_data['downpayment']; ?>%</strong> <br>
                                                        <small>Down Payment</small></span>
                                                    </div>
                                                    <div class="mx-2">|</div>
                                                    <div class="w-50">
                                                        <span><strong><?php echo $project_data['payments']; ?></strong><br>
                                                        <small>Installments</small></span>
                                                    </div>
                                                </div>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-3 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p><strong>Hand Over Date</strong></p>
                                        </div>
                                        <div class="pb-2">
                                            <i class="fa-solid fa-calendar-days"></i>
                                        </div>
                                        <div>
                                            <p><?php echo $project_data['delivery_date']; ?></p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-3 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p><strong>Tapu Type</strong></p>
                                        </div>
                                        <div class="pb-2">
                                            <i class="fa-solid fa-file"></i>
                                        </div>
                                        <div>
                                            <p><?php echo $project_data['tapu']; ?></p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="details-box">
                        <div>
                            <h4>Real Estate Information</h4>
                        </div>
                        <div>
                            <?php echo $project_data['project_information']; ?>
                        </div>
                    </div>

                    <div class="details-box">
                        <div class="container p-0">
                            <div class="row g-3">
                                <div>
                                    <h4>Location</h4>
                                </div>
                                
                                <?php if (isset($project_data['location_info']) && is_array($project_data['location_info'])): ?>
                                <div class="container">
                                    <div class="row g-3 mt-1">
                                        <?php foreach ($project_data['location_info'] as $location): ?>
                                            <div class="col-lg-4 col-md-12 col-sm-12">
                                                <div class="inner-details text-center">
                                                    <div class="pt-3 pb-3">
                                                        <!-- Embed the SVG directly from the URL -->
                                                        <div class="location-icon">
                                                            <img src="<?php echo $location['img']; ?>" alt="<?php echo $location['title']; ?>" class="location-icon">
                                                        </div>
                                                    </div>
                                                    <div>
                                                        <p class="m-0"><strong><?php echo $location['title']; ?></strong></p>
                                                        <p><?php echo $location['value'] . ' ' . $location['unit']; ?></p>
                                                    </div>
                                                </div>
                                            </div>
                                        <?php endforeach; ?>
                                    </div>

                                </div>
                                <?php else: ?>
                                    <p>No location information available.</p>
                                <?php endif; ?>


                            </div>
                        </div>
                    </div>
                    
                    <div class="details-box">
                        <div class="container p-0">
                            <div class="row g-3">
                                <div>
                                    <h4>Rooms & Prices</h4>
                                </div>
                                <div class="table-responsive">
                                    <table class="table room-details mb-0">
                                        <thead class="thead-dark">
                                            <tr>
                                                <th scope="col">Patterns</th>
                                                <th scope="col">Rooms</th>
                                                <th scope="col">Lounges</th>
                                                <th scope="col">Area</th>
                                                <th scope="col">Price</th>
                                                <th scope="col">Floor Plans</th>
                                            </tr>
                                        </thead>
                                        <tbody>
                                            <?php foreach ($project_data['rooms_prices'] as $room) : ?>
                                                <tr>
                                                    <td><?php echo esc_html($room['pattern']); ?></td>
                                                    <td><?php echo esc_html($room['room']); ?></td>
                                                    <td><?php echo esc_html($room['lounge']); ?></td>
                                                    <td><?php echo esc_html($room['min_area']); ?> - <?php echo esc_html($room['max_area']); ?> <span>m</span><sup>2</sup></td>
                                                    <td><?php echo number_format($room['min_price'], 0, '.', ','); ?> - <?php echo number_format($room['max_price'], 0, '.', ','); ?> <small><?php echo $selected_currency; ?></small></td>
                                                    <td>
                                                        <?php if (!empty($room['img'])) : // Check if the image URL is not null ?>
                                                            <a href="<?php echo esc_url($room['img']); ?>" data-fancybox="roomsGallery" class="fancybox-slide">
                                                                <img src="<?php echo esc_url($room['img']); ?>" class="img-fluid" alt="Floor Plan">
                                                            </a>
                                                        <?php else : // If the image URL is empty ?>
                                                        -
                                                        <?php endif; ?>
                                                    </td>
                                                </tr>
                                            <?php endforeach; ?>
                                        </tbody>
                                    </table>
                                </div>
                                <div>
                                    <p class="text-center">
                                        <strong>Note: These prices do not include discounts</strong>
                                        <strong>
                                            <?php 
                                            if (!empty($project_data['discount_percentage'])) {
                                                echo esc_html($project_data['discount_percentage']) . '%';
                                            }
                                            ?>
                                        </strong>
                                    </p>
                                    <p class="text-center">Latest price update 
                                        <span>
                                            <?php 
                                            if (!empty($project_data['last_price_update'])) {
                                                $date = new DateTime($project_data['last_price_update']); 
                                                echo $date->format('d-m-Y'); 
                                            } else {
                                                echo '-';
                                            }
                                            ?>
                                        </span>
                                    </p>
                                </div>
                            </div>
                        </div>
                    </div>
                    
                    <div class="details-box">
                        <div class="container p-0">
                            <div class="row g-3">
                                <div>
                                    <h4>Floor Plans</h4>
                                </div>
                                <?php foreach ($project_data['rooms_prices'] as $room) : ?>
                                    <?php if (!empty($room['img'])) : // Check if the image URL is not null ?>
                                        <div class="col-lg-4 col-md-6 col-12 mb-2">
                                            <a href="<?php echo esc_url($room['img']); ?>" data-fancybox="gallery" class="fancybox-slide">
                                                <img src="<?php echo esc_url($room['img']); ?>" class="img-fluid" alt="Room Image">
                                            </a>
                                        </div>
                                    <?php endif; ?>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>

                    <div class="details-box long-list">
                        <div>
                            <h4>Why this</h4>
                        </div>
                        <div>
                            <?php echo $project_data['why_this']; ?>
                        </div>

                    </div>
                    
                    <div class="details-box">
                        <div class="container p-0">
                            <div class="row g-3">
                                <div>
                                    <h4>Services</h4>
                                </div>
                                <div class="container">
                                    <ul class="row list-custom">
                                        <?php foreach ($project_data['services'] as $service) : ?>
                                            <li class="col-6 col-sm-6 col-md-4 d-flex align-items-center">
                                                <i class="fa-solid fa-circle-check"></i>
                                                <?php echo esc_html($service['title']); ?>
                                            </li>
                                        <?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="details-box">
                        <div class="map">
                            <?php
                            // Accessing the latitude and longitude from the location_map array
                            $latitude = $project_data['location_map'][0];
                            $longitude = $project_data['location_map'][1];
                            ?>
                            <iframe
                                src="https://maps.google.com/maps?q=<?php echo $latitude; ?>,<?php echo $longitude; ?>&t=&z=13&ie=UTF8&iwloc=&output=embed"
                                width="100%" height="400"></iframe>
                        </div>
                    </div>


                    <div class="details-box stat-details">
                        <div class="container p-0">
                            <div class="row g-3">
                                <div>
                                    <h4>Area Details</h4>
                                </div>
                                <div class="col-lg-3 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">Population</p>
                                            <p class="number m-0"><?php echo number_format($project_data['location_text']['population'], 0, '.', ','); ?></p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-3 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">Male Sex Ratio</p>
                                            <p class="number m-0"><?php echo $project_data['location_text']['male']; ?>%</p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-3 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">Female Sex Ratio</p>
                                            <p class="number m-0"><?php echo $project_data['location_text']['female']; ?>%</p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-3 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">Class</p>
                                            <p class="number m-0"><?php echo $project_data['location_text']['rate']; ?></p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="details-box stat-details">
                        <div class="container p-0">
                            <div class="row g-3">
                                <div>
                                    <h4>Price Change</h4>
                                </div>
                                <div class="col-lg-4 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">1 Year</p>
                                            <p class="number m-0">
                                                <?php echo $project_data['location_text']['p1']; ?>%
                                            </p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">3 Years</p>
                                            <p class="number m-0">
                                                <?php echo $project_data['location_text']['p2']; ?>%
                                            </p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">5 Years</p>
                                            <p class="number m-0">
                                                <?php echo $project_data['location_text']['p3']; ?>%
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Sticky Sidebar with Details -->
                <div class="col-lg-4 col-md-12 col-sm-12 sticky-column">
                    <div class="details-box">
                        <table class="table custom-table m-0">
                            <tbody>
                                <?php if (!empty($project_data['extra_attributes']['number_of_blocks'])): ?>
                                <tr>
                                    <td><strong>Number of Blocks</strong></td>
                                    <td class="text-end"><?php echo $project_data['extra_attributes']['number_of_blocks']; ?></td>
                                </tr>
                                <?php endif; ?>
                                <?php if (!empty($project_data['extra_attributes']['number_of_apartment'])): ?>
                                <tr>
                                    <td><strong>Number of Apartment</strong></td>
                                    <td class="text-end"><?php echo $project_data['extra_attributes']['number_of_apartment']; ?></td>
                                </tr>
                                <?php endif; ?>
                                
                                <?php if (!empty($project_data['extra_attributes']['number_of_floors'])): ?>
                                <tr>
                                    <td><strong>Number of Floors</strong></td>
                                    <td class="text-end"><?php echo $project_data['extra_attributes']['number_of_floors']; ?></td>
                                </tr>
                                <?php endif; ?>
                                
                                <?php if (!empty($project_data['extra_attributes']['number_of_Shops'])): ?>
                                <tr>
                                    <td><strong>Number of Shops</strong></td>
                                    <td class="text-end"><?php echo $project_data['extra_attributes']['number_of_Shops']; ?></td>
                                </tr>
                                <?php endif; ?>
                                <?php if (!empty($area)): ?>
                                <tr>
                                    <td><strong>Area</strong></td>
                                    <td class="text-end"><?php echo $area; ?> <span>m<sup>2</sup></span></td>
                                </tr>
                                <?php endif; ?>
                                <?php if (!empty($project_data['extra_attributes']['view'])): ?>
                                <tr>
                                    <td><strong>View</strong></td>
                                    <td class="text-end">
                                        <?php echo implode(', ', $project_data['extra_attributes']['view']); ?>
                                    </td>
                                </tr>
                                <?php endif; ?>
                                <?php if (!empty($project_data['extra_attributes']['kdv'])): ?>
                                <tr>
                                    <td><strong>KDV</strong></td>
                                    <td class="text-end"><?php echo $project_data['extra_attributes']['kdv']; ?><span>%</span></td>
                                </tr>
                                <?php endif; ?>
                                
                                <?php if (!empty($project_data['extra_attributes']['tapu_fees'])): ?>
                                <tr>
                                    <td><strong>Tapu Fees</strong></td>
                                    <td class="text-end"><?php echo $project_data['extra_attributes']['tapu_fees']; ?><span>%</span></td>
                                </tr>
                                <?php endif; ?>
                                <?php if (!empty($project_data['tapu'])): ?>
                                <tr>
                                    <td><strong>Tapu Type</strong></td>
                                    <td class="text-end"><?php echo $project_data['tapu']; ?></td>
                                </tr>
                                <?php endif; ?>
                                <?php if (isset($project_data['extra_attributes']['turkish_nationality']) && $project_data['extra_attributes']['turkish_nationality'] == 1): ?>
                                <tr>
                                    <td><strong>Turkish Nationality</strong></td>
                                    <td class="text-end">Yes</td>
                                </tr>
                                <?php endif; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php
}

get_header();  // Include the header

?>

<div class="single-project">
    <?php if ( $project_id ): ?>
        <?php load_single_project_template(project_data: $project_data); ?>
    <?php else: ?>
        <p>No project ID was provided in the URL.</p>
    <?php endif; ?>
</div>

<?php

get_footer();  // Include the footer