<?php

function load_properties_template($property_data) {
    $selected_currency = isset($_COOKIE['selected_currency']) ? $_COOKIE['selected_currency'] : 'USD';  
    $price = number_format($property_data['disp_price'], 2, '.', ',');
    ?>
    <div class="col-lg-4 col-md-6 col-sm-12 mb-4">
        <div class="card custom-card h-100">
          <div class="image-container">
            <a href="/single-resale/?property_id=<?php echo esc_html($property_data['slug']); ?>">
                <img src="<?php echo esc_url($property_data['main_pic']); ?>" class="card-img-top" alt="<?php echo esc_attr($property_data['title']); ?>">
            </a>
          </div>
          <div class="card-body">
            <div class="upper-part">
              <span class="badge card-badge"><?php echo esc_html($property_data['code']); ?></span>
              <h3 class="card-price" dir="ltr">
                <span><?php echo esc_html($price); ?>
                  <small class="text-uppercase currency"><?php echo $selected_currency; ?></small>
                </span>
              </h3>
              <h6 class="card-title">
                <a href="/single-property/?property_id=<?php echo esc_html($property_data['slug']); ?>" class="card-title-link verified prt-link-detail">
                  <?php echo esc_html($property_data['title']); ?>
                </a>
              </h6>
            </div>
            <div class="lower-part">
              <hr class="divider">
              <div class="location-area">
                <span class="location">
                  <span class="icon">
                    <i class="fa-solid fa-location-dot"></i>
                  </span>
                  <?php echo esc_html($property_data['location_text']['title']); ?>
                </span>
                <span class="area">
                  <span class="icon">
                    <i class="fa-solid fa-bed"></i>
                  </span>
                  <?php echo esc_html($property_data['rooms_prices']['room']); ?> + <?php echo esc_html($property_data['rooms_prices']['lounge']); ?>
                </span>
                <span class="area">
                  <span class="icon">
                    <i class="fa-solid fa-vector-square"></i>
                  </span>
                  <?php echo esc_html($property_data['rooms_prices']['area']); ?> m2
                </span>
              </div>
              <hr class="divider">
              <a href="/single-resale/?property_id=<?php echo esc_html($property_data['slug']); ?>" class="btn btn-primary">View Details</a>
            </div>
          </div>
        </div>
    </div>
    <?php
}
require_once plugin_dir_path(__FILE__) . 'property-filters.php';
require_once plugin_dir_path(__FILE__) . '../sort-box.php';

// Fetch the properties Page ID dynamically
$properties_page = get_page_by_title( 'Resale' );
$property_page_id = $properties_page ? $properties_page->ID : null;

// Get the current page number from the URL or default to 1
$current_page = isset($_GET['pg']) ? (int) $_GET['pg'] : 1;

// Check for additional parameters in the URL
$keyword = isset($_GET['q']) ? sanitize_text_field($_GET['q']) : '';
$city = isset($_GET['city']) ? sanitize_text_field($_GET['city']) : '';
$town = isset($_GET['town']) ? sanitize_text_field($_GET['town']) : '';
$category = isset($_GET['category']) ? sanitize_text_field($_GET['category']) : '';
$patterns = isset($_GET['patterns']) ? sanitize_text_field($_GET['patterns']) : '';
$rooms = isset($_GET['rooms']) ? sanitize_text_field($_GET['rooms']) : '';
$lounges = isset($_GET['lounges']) ? sanitize_text_field($_GET['lounges']) : '';
$min_price = isset($_GET['min-price']) ? (int)$_GET['min-price'] : '';
$max_price = isset($_GET['max-price']) ? (int)$_GET['max-price'] : '';

// Fetch data from the API with the page parameter
$properties_data = emlak_real_estate_fetch_properties($current_page, $city, $town, $category, $patterns, $rooms, $lounges, $min_price, $max_price, $keyword);
// $properties_data = emlak_real_estate_fetch_properties($current_page);

// Total number of pages (from API response)
$last_page = isset($properties_data['last_page']) ? (int) $properties_data['last_page'] : 1;

get_header();  // Include the header

// Check if the current page is the "Lands Page"
if (is_page($property_page_id)) {
    echo render_property_filter();
    // Display lands if available
    if (!empty($properties_data['data'])) {
        echo getInfoBox($properties_data['total'], $properties_page->post_title);
        echo '<div class="properties-container container mt-5"><div class="row">';
        foreach ($properties_data['data'] as $property) {
            // Call the function to load the template with the land data
            load_properties_template($property);
        }
        echo '</div></div>';
        
        // Use the pagination function
        // Prepare filters as an associative array
        $filters = [
          'city' => $city,
          'town' => $town,
          'category' => $category,
          'patterns' => $patterns,
          'rooms' => $rooms,
          'lounges' => $lounges,
          'min-price' => $min_price,
          'max-price' => $max_price,
        ];

      // Use the pagination function
      echo generate_pagination_links($current_page, $last_page, '/resale', $filters);
    } else {
        echo '<div class="container empty-loop mt-5"><div class="row">';
        echo '<p>No resales available at the moment.</p>';
        echo '</div></div>';
    }
} else {
    // Default behavior for other pages/posts
    if (have_posts()) {
        while (have_posts()) {
            the_post();
            the_content();
        }
    }
}

get_footer();  // Include the footer
