<?php
function render_property_filter() {
    // Define the options for the dropdowns
    $cities = emlak_real_estate_fetch_cities('resale');
    $categories = [];
    $patterns = ["flat" => "Flat", "villa" => "Villa", "duplex" => "Duplex", "penthouse" => "Penthouse", "office" => "Office", "shop" => "Shop", "triplex" => "Triplex", "home_office" => "Home Office"];
    $rooms = ["1" => "1", "1.5" => "1.5", "2" => "2", "2.5" => "2.5", "3" => "3", "3.5" => "3.5", "4" => "4", "4.5" => "4.5", "5" => "5", "5.5" => "5.5", "6" => "6", "6.5" => "6.5", "7" => "7", "8" => "8", "10" => "10"];
    $lounges = ["0.5" => "0.5", "1" => "1", "1.5" => "1.5", "2" => "2", "3" => "3"];
    ob_start(); // Start output buffering
    ?>
    <div class="container-fluid primary-section">
        <div class="container search-bar">
            <div class="row">
                <div class="col-12">
                    <label><small>Search with Keyword</small></label>
                </div>
                <div class="col-12 d-flex my-0">
                    <!-- Added id="keyword" for JavaScript to access it -->
                    <input type="text" class="form-control search-keyword" id="keyword_properties" placeholder="Search by keyword" aria-label="Search by keyword">
                    <button class="btn btn-primary search-btn" onclick="updateURLProperties()">
                        <i class="fa-solid fa-magnifying-glass"></i>
                    </button>
                </div>
            </div>
            <div class="row">
                <div class="col-12 text-center mt-3">
                    <button class="filters-btn" type="button" data-bs-toggle="collapse" data-bs-target="#moreFilters" aria-expanded="false" aria-controls="moreFilters">
                        Open Advanced Filters <i class="fa-solid fa-sliders"></i>
                    </button>
                </div>
            </div>
            <div class="row collapse" id="moreFilters">
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>City</small></label>
                    <select class="form-select select2" id="city" placeholder="City">
                        <option value="" selected>Select City</option>
                        <?php foreach ($cities as $key => $city) : ?>
                            <option value="<?php echo $key; ?>"><?php echo $city; ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>Town</small></label>
                    <select class="form-select select2" id="town" placeholder="Town">
                        <option value="" selected>Select Town</option>
                    </select>
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>Category</small></label>
                    <select class="form-select select2" id="category" placeholder="Category">
                        <option value="" selected>Select Category</option>
                        <?php foreach ($categories as $key => $category) : ?>
                            <option value="<?php echo $key; ?>"><?php echo $category; ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>Patterns</small></label>
                    <select class="form-select select2" id="patterns" placeholder="Patterns">
                        <option value="" selected>Select Pattern</option>
                        <?php foreach ($patterns as $key => $pattern) : ?>
                            <option value="<?php echo $key; ?>"><?php echo $pattern; ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>Rooms</small></label>
                    <select class="form-select select2" id="rooms" placeholder="Rooms">
                        <option value="" selected>Select Room</option>
                        <?php foreach ($rooms as $key => $room) : ?>
                            <option value="<?php echo $key; ?>"><?php echo $room; ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>Lounges</small></label>
                    <select class="form-select select2" id="lounges" placeholder="Lounges">
                        <option value="" selected>Select Lounge</option>
                        <?php foreach ($lounges as $key => $lounge) : ?>
                            <option value="<?php echo $key; ?>"><?php echo $lounge; ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>Min Price</small></label>
                    <input type="number" class="form-control" placeholder="Min Price" id="minPrice">
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3">
                    <label><small>Max Price</small></label>
                    <input type="number" class="form-control" placeholder="Max Price" id="maxPrice">
                </div>
                <div class="col-lg-4 col-md-6 col-sm-12 mt-3 d-flex align-items-end">
                    <button class="submit-btn" type="button" onclick="updateURLProperties()">
                        Search
                    </button>
                </div>
            </div>
        </div>
    </div>

    <script>
        const $ = jQuery;
        jQuery(document).ready(function($) {
            
            // Function to fetch places based on selected city using async/await
            async function fetchPlaces(cityId, model) {
                try {
                    const response = await $.ajax({
                        url: emlak_ajax.ajax_url,
                        method: 'POST',
                        data: {
                            action: 'fetch_town',
                            city_id: cityId,
                            model: model
                        }
                    });
            
                    var placesSelect = $('#town');
                    placesSelect.empty();
            
                    if (response.success) {
                        // Populate places into the select dropdown
                        placesSelect.append(new Option('Select Town', ''));
                        response.data.forEach(function(place) {
                            placesSelect.append(new Option(place.title, place.id));
                        });
                    } else {
                        console.error(response.data.error || 'Error fetching places.');
                    }
                } catch (error) {
                    console.error('Failed to fetch places.', error);
                }
            }
        
            // Event listener for when a city is selected
            $('#city').change(async function () {
                var selectedCityId = $(this).val();
            
                // Check if #category or #town has a selected option (not the default empty option)
                if ($('#category').val() || $('#town').val()) {
                    // If they have selected options, clear them and set the default option
                    $("#category").empty().append(new Option('Select Category', ''));
                    $("#town").empty().append(new Option('Select Town', ''));
                }
            
                // Fetch places based on the selected city
                if (selectedCityId) {
                    await fetchPlaces(selectedCityId, 'resale');
                }
            });
            
            async function fetchNextFilter(currentFilter, filters) {
                
                $.ajax({
                    url: emlak_ajax.ajax_url,
                    type: 'POST',
                    data: {
                        action: 'fetch_next_filter',
                        currentFilter: currentFilter,
                        model: filters.model,
                        city: filters.city || '',
                        town: filters.town || '',
                        category: filters.category || '',
                        pattern: filters.patternId || '',
                        room: filters.roomId || ''
                    },
                    dataType: 'json',
                    success: function (response) {
                        if (response.error) {
                            console.error(response.error);
                        } else {
                            if (currentFilter === 'town'){
                                const categorySelect = $("#category");
                                categorySelect.empty();
                                categorySelect.append(new Option('Select Category', ''));
                                
                                if (Array.isArray(response) && response.length > 0) {
                                    response.forEach(function (category) {
                                        categorySelect.append(new Option(category.title, category.id));
                                    });
                                } else {
                                    console.warn('No data available or not in the expected format.');
                                }
                            }else if (currentFilter === 'category'){
                                const patternsSelect = $("#patterns");
                                patternsSelect.empty();
                                patternsSelect.append(new Option('Select Pattern', ''));
                                
                                // Check if response is an array or an object
                                if (Array.isArray(response)) {
                                    // If it's an array, loop through it directly
                                    response.forEach(function (pattern) {
                                        patternsSelect.append(new Option(pattern.title, pattern.id));
                                    });
                                } else if (typeof response === 'object' && response !== null) {
                                    // If it's an object, convert it to an array of [key, value] pairs and loop through it
                                    Object.entries(response).forEach(([key, value]) => {
                                        patternsSelect.append(new Option(value, key));
                                    });
                                } else {
                                    console.warn('No data available or not in the expected format.');
                                }
                            }else if (currentFilter === 'pattern'){
                                const roomsSelect = $("#rooms");
                                roomsSelect.empty();
                                roomsSelect.append(new Option('Select Room', ''));
                                
                                // Check if response is an array or an object
                                if (Array.isArray(response)) {
                                    // If it's an array, loop through it directly
                                    response.forEach(function (roomNumber) {
                                        roomsSelect.append(new Option(roomNumber, roomNumber));
                                    });
                                } else if (typeof response === 'object' && response !== null) {
                                    // If it's an object, loop through its values
                                    Object.values(response).forEach(roomNumber => {
                                        roomsSelect.append(new Option(roomNumber, roomNumber));
                                    });
                                } else {
                                    console.warn('No data available or not in the expected format.');
                                }
                            }else if (currentFilter === 'room'){
                                const loungesSelect = $("#lounges");
                                loungesSelect.empty();
                                loungesSelect.append(new Option('Select Lounge', ''));
                                
                                // Check if response is an array or an object
                                if (Array.isArray(response)) {
                                    // If it's an array, loop through it directly
                                    response.forEach(function (loungeNumber) {
                                        loungesSelect.append(new Option(loungeNumber, loungeNumber));
                                    });
                                } else if (typeof response === 'object' && response !== null) {
                                    // If it's an object, loop through its values
                                    Object.values(response).forEach(loungeNumber => {
                                        loungesSelect.append(new Option(loungeNumber, loungeNumber));
                                    });
                                } else {
                                    console.warn('No data available or not in the expected format.');
                                }
                            }
                        }
                    },
                    error: function () {
                        console.error('Error fetching next filter.');
                    }
                });
            }

            $('#town, #category, #patterns, #rooms').change(function () {
                const filters = {
                    model: 'resale',
                    city: $('#city').val(),
                    town: $('#town').val(),
                    category: $('#category').val(),
                    patternId: $('#patterns').val(),
                    roomId: $('#rooms').val()
                };
            
                // Detect which filter was changed
                const changedFilter = $(this).attr('id');
            
                // Reset subsequent filters based on the current selection
                if (changedFilter === 'town') {
                    $('#category').val('');
                    filters.category = '';
                } else if (changedFilter === 'category') {
                    $('#patterns').val('');
                    filters.patternId = '';
                } else if (changedFilter === 'patterns') {
                    $('#rooms').val('');
                    filters.roomId = '';
                }
            
                // Now decide which filter to fetch next
                if (filters.city && filters.town && !filters.category) {
                    fetchNextFilter('town', filters);
                } else if (filters.city && filters.town && filters.category && !filters.patternId) {
                    // Fetch pattern options if patternId is empty
                    fetchNextFilter('category', filters);
                } else if (filters.city && filters.town && filters.category && filters.patternId && !filters.roomId) {
                    // Fetch room options if roomId is empty
                    fetchNextFilter('pattern', filters);
                } else if (filters.city && filters.town && filters.category && filters.patternId && filters.roomId) {
                    // All filters filled, fetch final data
                    fetchNextFilter('room', filters);
                }
            });

            // Function to get URL parameters
            function getURLParameter(name) {
                const urlParams = new URLSearchParams(window.location.search);
                return urlParams.get(name) || '';
            }

            // Updated window.onload function with loading overlay
            window.onload = async function() {
                const city = getURLParameter('city');
                const town = getURLParameter('town');
                const category = getURLParameter('category');
                const patterns = getURLParameter('patterns');
                const rooms = getURLParameter('rooms');
                const lounges = getURLParameter('lounges');
                const minPrice = getURLParameter('min-price');
                const maxPrice = getURLParameter('max-price');
                const keyword = getURLParameter('q');
            
                try {
                    // If city parameter exists, select city and fetch towns
                    if (city) {
                        await fetchPlaces(selectedCityId, 'resale');
                    }
            
                    // If town parameter exists, select values
                    if (town) {
                        await fetchNextFilter('town', {
                            model: 'resale',
                            city: city,
                            town: town,
                            category: '',
                            patternId: '',
                            roomId: ''
                        });
                    }
            
                    if (category) {
                        await fetchNextFilter('category', {
                            model: 'resale',
                            city: city,
                            town: town,
                            category: category,
                            patternId: '',
                            roomId: ''
                        });
                    }
            
                    if (patterns) {
                        await fetchNextFilter('pattern', {
                            model: 'resale',
                            city: city,
                            town: town,
                            category: category,
                            patternId: patterns,
                            roomId: ''
                        });
                    }
                    
                    if (rooms) {
                        await fetchNextFilter('room', {
                            model: 'resale',
                            city: city,
                            town: town,
                            category: category,
                            patternId: patterns,
                            roomId: rooms
                        });
                    }
                    
                    setTimeout(() => {
                        // Check if each value exists and set it for the corresponding Select2 element
                        if (city) jQuery('#city').val(city).trigger('change.select2');
                        if (town) jQuery('#town').val(town).trigger('change.select2');
                        if (category) jQuery('#category').val(category).trigger('change.select2');
                        if (patterns) jQuery('#patterns').val(patterns).trigger('change.select2');
                        if (rooms) jQuery('#rooms').val(rooms).trigger('change.select2');
                        if (lounges) jQuery('#lounges').val(lounges).trigger('change.select2');
                    }, 3000);

                    // Set values for regular text/number inputs if parameters exist
                    if (minPrice) document.getElementById('minPrice').value = minPrice;
                    if (maxPrice) document.getElementById('maxPrice').value = maxPrice;
                    if (keyword) document.getElementById('keyword').value = keyword;
            
                } catch (error) {
                    console.error('Error during the fetch process:', error);
                }
            };
        });
        
        function updateURLProperties() {
            const city = document.getElementById('city').value;
            const town = document.getElementById('town').value;
            const category = document.getElementById('category').value;
            const patterns = document.getElementById('patterns').value;
            const rooms = document.getElementById('rooms').value;
            const lounges = document.getElementById('lounges').value;
            const minPrice = document.getElementById('minPrice').value;
            const maxPrice = document.getElementById('maxPrice').value;
            const keyword = document.getElementById('keyword_properties').value;
    
            let url = '/resale/?';
            if (city) url += '&city=' + encodeURIComponent(city);
            if (town) url += '&town=' + encodeURIComponent(town);
            if (category) url += '&category=' + encodeURIComponent(category);
            if (patterns) url += '&patterns=' + encodeURIComponent(patterns);
            if (rooms) url += '&rooms=' + encodeURIComponent(rooms);
            if (lounges) url += '&lounges=' + encodeURIComponent(lounges);
            if (minPrice) url += '&min-price=' + encodeURIComponent(minPrice);
            if (maxPrice) url += '&max-price=' + encodeURIComponent(maxPrice);
            if (keyword) url += '&q=' + encodeURIComponent(keyword);
    
            window.location.href = url;
        }
    </script>
    <?php
    return ob_get_clean();
}
?>
