<?php

// Get the property_id from the URL parameter using $_GET without casting it to an integer
$property_id = isset($_GET['property_id']) ? sanitize_text_field($_GET['property_id']) : '';
$property_data = emlak_get_property_by_id($property_id);

function load_single_property_template($property_data){
    $selected_currency = isset($_COOKIE['selected_currency']) ? $_COOKIE['selected_currency'] : 'USD';  
    $price = number_format($property_data['disp_price'], 2, '.', ',');
    ?>
    <div class="container-fluid primary-section">
        <div class="container px-0">
            <div class="row">
                <div class="col-lg-12 col-md-12 col-sm-12">
                    <h1 class="mx-0 my-0"><?php echo $property_data['title']; ?></h1>
                    <p class="pt-2"><?php echo $property_data['description']; ?></p>
                </div>
            </div>
        </div>
    </div>

    <div class="container-fluid single-land px-0">
        <div class="container pt-5 pb-5">
            <div class="row">
                <div class="col-lg-8 col-md-12 col-sm-12">
                    <!-- Carousel for images with Fancybox -->
                    <div id="landCarousel" class="carousel slide" data-bs-ride="carousel">
                        <div class="carousel-inner">
                            <?php 
                            // Assuming $property_data['pics'] contains the array of image URLs
                            $pics = $property_data['pics'];
                            foreach ($pics as $index => $pic) {
                                // Check if it's the first item to set it as active
                                $activeClass = ($index === 0) ? 'active' : '';
                                echo '<div class="carousel-item ' . $activeClass . '">';
                                echo '<a href="' . $pic . '" data-fancybox="landImages">';
                                echo '<img src="' . $pic . '" class="d-block w-100" alt="Land Image ' . ($index + 1) . '">';
                                echo '</a>';
                                echo '</div>';
                            }
                            ?>
                        </div>
                        <button class="carousel-control-prev" type="button" data-bs-target="#landCarousel" data-bs-slide="prev">
                            <span class="carousel-control-prev-icon" aria-hidden="true"></span>
                            <span class="visually-hidden">Previous</span>
                        </button>
                        <button class="carousel-control-next" type="button" data-bs-target="#landCarousel" data-bs-slide="next">
                            <span class="carousel-control-next-icon" aria-hidden="true"></span>
                            <span class="visually-hidden">Next</span>
                        </button>
                    </div>

                    <div class="details-box">
                        <div class="container p-0">
                            <div class="row g-3">
                                <div class="col-lg-4 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p><strong>Location</strong></p>
                                        </div>
                                        <div class="pb-2">
                                            <i class="fa-solid fa-location-crosshairs"></i>
                                        </div>
                                        <div>
                                            <p><?php echo $property_data['location_text']['title']; ?></p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p><strong>Price</strong></p>
                                        </div>
                                        <div class="pb-2">
                                            <i class="fa-solid fa-money-bill-1-wave"></i>
                                        </div>
                                        <div>
                                            <p>
                                                <span><?php echo $price; ?>
                                                    <small class="text-uppercase currency"><?php echo $selected_currency; ?></small>
                                                </span>
                                            </p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p><strong>Rooms & Space</strong></p>
                                        </div>
                                        <div class="pb-2">
                                            <i class="fa-solid fa-bed"></i> - <i class="fa-solid fa-vector-square"></i>
                                        </div>
                                        <div>
                                            <p>
                                                <?php echo esc_html($property_data['rooms_prices']['room']); ?> + <?php echo esc_html($property_data['rooms_prices']['lounge']); ?> - 
                                                <?php echo esc_html($property_data['rooms_prices']['area']); ?> m2
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="details-box">
                        <div>
                            <h4>Real Estate Information</h4>
                        </div>
                        <div>
                            <?php echo $property_data['project_information']; ?>
                        </div>
                    </div>

                    <div class="details-box">
                        <div class="map">
                            <?php
                            // Accessing the latitude and longitude from the location_map array
                            $latitude = $property_data['location_map'][0];
                            $longitude = $property_data['location_map'][1];
                            ?>
                            <iframe
                                src="https://maps.google.com/maps?q=<?php echo $latitude; ?>,<?php echo $longitude; ?>&t=&z=13&ie=UTF8&iwloc=&output=embed"
                                width="100%" height="400"></iframe>
                        </div>
                    </div>


                    <div class="details-box stat-details">
                        <div class="container p-0">
                            <div class="row g-3">
                                <div>
                                    <h4>Area Details</h4>
                                </div>
                                <div class="col-lg-3 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">Population</p>
                                            <p class="number m-0"><?php echo number_format($property_data['location_text']['population'], 0, '.', ','); ?></p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-3 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">Male Sex Ratio</p>
                                            <p class="number m-0"><?php echo $property_data['location_text']['male']; ?>%</p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-3 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">Female Sex Ratio</p>
                                            <p class="number m-0"><?php echo $property_data['location_text']['female']; ?>%</p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-3 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">Class</p>
                                            <p class="number m-0"><?php echo $property_data['location_text']['rate']; ?></p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>

                    <div class="details-box stat-details">
                        <div class="container p-0">
                            <div class="row g-3">
                                <div>
                                    <h4>Price Change</h4>
                                </div>
                                <div class="col-lg-4 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">1 Year</p>
                                            <p class="number m-0">
                                                <?php echo $property_data['location_text']['p1']; ?>%
                                            </p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">3 Years</p>
                                            <p class="number m-0">
                                                <?php echo $property_data['location_text']['p2']; ?>%
                                            </p>
                                        </div>
                                    </div>
                                </div>
                                <div class="col-lg-4 col-md-12 col-sm-12">
                                    <div class="inner-details text-center">
                                        <div>
                                            <p class="m-0">5 Years</p>
                                            <p class="number m-0">
                                                <?php echo $property_data['location_text']['p3']; ?>%
                                            </p>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>

                <!-- Sticky Sidebar with Details -->
                <div class="col-lg-4 col-md-12 col-sm-12 sticky-column">
                    <div class="details-box">
                        <table class="table custom-table m-0">
                            <tbody>
                                <tr>
                                    <td><strong>Construction Age</strong></td>
                                    <td class="text-end"><?php echo $property_data['construction_age']; ?></td>
                                </tr>
                                <tr>
                                    <td><strong>Number Of Bathrooms</strong></td>
                                    <td class="text-end"><?php echo $property_data['number_of_bathrooms']; ?></td>
                                </tr>
                                <tr>
                                    <td><strong>Plaque Count</strong></td>
                                    <td class="text-end"><?php echo $property_data['plaque_count']; ?></td>
                                </tr>
                                <tr>
                                    <td><strong>Floor</strong></td>
                                    <td class="text-end"><?php echo $property_data['floor']; ?></td>
                                </tr>
                                <tr>
                                    <td><strong>Proceeds</strong></td>
                                    <td class="text-end"><?php echo $property_data['proceeds']; ?> <span class="currency"><?php echo $selected_currency; ?></span></td>
                                </tr>
                                <tr>
                                    <td><strong>Number of Kitchens</strong></td>
                                    <td class="text-end"><?php echo $property_data['number_of_kitchens']; ?></td>
                                </tr>
                                <tr>
                                    <td><strong>Kitchen Type</strong></td>
                                    <td class="text-end"><?php echo $property_data['kitchen_type']; ?></td>
                                </tr>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
    <?php
}

get_header();  // Include the header

?>

<div class="single-property">
    <?php if ( $property_id ): ?>
        <?php load_single_property_template(property_data: $property_data); ?>
    <?php else: ?>
        <p>No property ID was provided in the URL.</p>
    <?php endif; ?>
</div>

<?php

get_footer();  // Include the footer